#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-install
version:              3.10.3.0
visibility:           public
id:                   cabal-install-3.10.3.0-JUj8MFbvf603dY2CWprG1C
key:                  cabal-install-3.10.3.0-JUj8MFbvf603dY2CWprG1C
license:              BSD-3-Clause
copyright:            2003-2023, Cabal Development Team
maintainer:           Cabal Development Team <cabal-devel@haskell.org>
author:               Cabal Development Team (see AUTHORS file)
homepage:             http://www.haskell.org/cabal/
synopsis:             The command-line interface for Cabal and Hackage.
description:
    The \'\''cabal\'\'' command-line program simplifies the process of managing
    Haskell software by automating the fetching, configuration, compilation
    and installation of Haskell libraries and programs.

category:             Distribution
abi:                  bec619f85c84e57d4534868802a38765
exposed:              True
exposed-modules:
    Distribution.Client.BuildReports.Anonymous
    Distribution.Client.BuildReports.Lens
    Distribution.Client.BuildReports.Storage
    Distribution.Client.BuildReports.Types
    Distribution.Client.BuildReports.Upload Distribution.Client.Check
    Distribution.Client.CmdBench Distribution.Client.CmdBuild
    Distribution.Client.CmdClean Distribution.Client.CmdConfigure
    Distribution.Client.CmdErrorMessages Distribution.Client.CmdExec
    Distribution.Client.CmdFreeze Distribution.Client.CmdHaddock
    Distribution.Client.CmdHaddockProject
    Distribution.Client.CmdInstall
    Distribution.Client.CmdInstall.ClientInstallFlags
    Distribution.Client.CmdInstall.ClientInstallTargetSelector
    Distribution.Client.CmdLegacy Distribution.Client.CmdListBin
    Distribution.Client.CmdOutdated Distribution.Client.CmdRepl
    Distribution.Client.CmdRun Distribution.Client.CmdSdist
    Distribution.Client.CmdTest Distribution.Client.CmdUpdate
    Distribution.Client.Compat.Directory
    Distribution.Client.Compat.ExecutablePath
    Distribution.Client.Compat.Orphans
    Distribution.Client.Compat.Prelude
    Distribution.Client.Compat.Semaphore Distribution.Client.Compat.Tar
    Distribution.Client.Config Distribution.Client.Configure
    Distribution.Client.Dependency Distribution.Client.Dependency.Types
    Distribution.Client.DistDirLayout Distribution.Client.Fetch
    Distribution.Client.FetchUtils Distribution.Client.FileMonitor
    Distribution.Client.Freeze Distribution.Client.GZipUtils
    Distribution.Client.GenBounds Distribution.Client.Get
    Distribution.Client.Glob Distribution.Client.GlobalFlags
    Distribution.Client.Haddock Distribution.Client.HashValue
    Distribution.Client.HttpUtils Distribution.Client.IndexUtils
    Distribution.Client.IndexUtils.ActiveRepos
    Distribution.Client.IndexUtils.IndexState
    Distribution.Client.IndexUtils.Timestamp Distribution.Client.Init
    Distribution.Client.Init.Defaults
    Distribution.Client.Init.FileCreators
    Distribution.Client.Init.FlagExtractors
    Distribution.Client.Init.Format
    Distribution.Client.Init.Interactive.Command
    Distribution.Client.Init.Licenses
    Distribution.Client.Init.NonInteractive.Command
    Distribution.Client.Init.NonInteractive.Heuristics
    Distribution.Client.Init.Prompt Distribution.Client.Init.Simple
    Distribution.Client.Init.Types Distribution.Client.Init.Utils
    Distribution.Client.Install Distribution.Client.InstallPlan
    Distribution.Client.InstallSymlink Distribution.Client.JobControl
    Distribution.Client.List Distribution.Client.Main
    Distribution.Client.Manpage Distribution.Client.ManpageFlags
    Distribution.Client.Nix Distribution.Client.NixStyleOptions
    Distribution.Client.PackageHash Distribution.Client.ParseUtils
    Distribution.Client.ProjectBuilding
    Distribution.Client.ProjectBuilding.Types
    Distribution.Client.ProjectConfig
    Distribution.Client.ProjectConfig.Legacy
    Distribution.Client.ProjectConfig.Types
    Distribution.Client.ProjectFlags
    Distribution.Client.ProjectOrchestration
    Distribution.Client.ProjectPlanOutput
    Distribution.Client.ProjectPlanning
    Distribution.Client.ProjectPlanning.Types
    Distribution.Client.RebuildMonad Distribution.Client.Reconfigure
    Distribution.Client.Run Distribution.Client.Sandbox
    Distribution.Client.Sandbox.PackageEnvironment
    Distribution.Client.SavedFlags Distribution.Client.ScriptUtils
    Distribution.Client.Security.DNS Distribution.Client.Security.HTTP
    Distribution.Client.Setup Distribution.Client.SetupWrapper
    Distribution.Client.Signal Distribution.Client.SolverInstallPlan
    Distribution.Client.SourceFiles Distribution.Client.SrcDist
    Distribution.Client.Store Distribution.Client.Tar
    Distribution.Client.TargetProblem
    Distribution.Client.TargetSelector Distribution.Client.Targets
    Distribution.Client.Types Distribution.Client.Types.AllowNewer
    Distribution.Client.Types.BuildResults
    Distribution.Client.Types.ConfiguredId
    Distribution.Client.Types.ConfiguredPackage
    Distribution.Client.Types.Credentials
    Distribution.Client.Types.InstallMethod
    Distribution.Client.Types.OverwritePolicy
    Distribution.Client.Types.PackageLocation
    Distribution.Client.Types.PackageSpecifier
    Distribution.Client.Types.ReadyPackage
    Distribution.Client.Types.Repo Distribution.Client.Types.RepoName
    Distribution.Client.Types.SourcePackageDb
    Distribution.Client.Types.SourceRepo
    Distribution.Client.Types.WriteGhcEnvironmentFilesPolicy
    Distribution.Client.Upload Distribution.Client.Utils
    Distribution.Client.Utils.Json Distribution.Client.Utils.Parsec
    Distribution.Client.VCS Distribution.Client.Version
    Distribution.Client.Win32SelfUpgrade
    Distribution.Deprecated.ParseUtils Distribution.Deprecated.ReadP
    Distribution.Deprecated.ViewAsFieldDescr

hidden-modules:       Paths_cabal_install
import-dirs:          /usr/lib/ghc-9.6.6/site-local/cabal-install-3.10.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cabal-install-3.10.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cabal-install-3.10.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cabal-install
hs-libraries:         HScabal-install-3.10.3.0-JUj8MFbvf603dY2CWprG1C
depends:
    Cabal-3.10.3.0 Cabal-syntax-3.10.3.0
    HTTP-4000.4.1-5E7T60cpr4dHee0oMOAWkI array-0.5.6.0
    async-2.2.6-LO8jXAjK6UhIKzHTrVwmLU base-4.18.2.1
    base16-bytestring-1.0.2.0-IJTPvkgxmT6En7SGGWVFMS binary-0.8.9.1
    bytestring-0.11.5.3
    cabal-install-solver-3.10.3.0-AVXAM6nWjQHEFlBraGxB9
    containers-0.6.7
    cryptohash-sha256-0.11.102.1-9ecSYhLshbvF4UBFFL1rOY
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    edit-distance-0.2.2.1-8ZKCdStM9ZtBRQI3vM5yT3 exceptions-0.10.7
    filepath-1.4.300.1 hackage-security-0.6.3.2-1ihvx1nerhwGYVa0vTDlDq
    hashable-1.4.7.0-HpPQsoREnwfDz6Qf16RXZ0
    lukko-0.1.2-Br7mRHmtylDA8hjbkmupqB mtl-2.3.1
    network-uri-2.6.4.2-5H6FsM3EemmJOLKW8jzcT0 parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-FIPqSdjH2h37Wl2rnOwKW
    regex-base-0.94.0.3-6fVrfocUW2t4u08iX8Rj6b
    regex-posix-0.96.0.2-LsCmj8tXKerCmkZ6TKO5qF
    resolv-0.2.0.3-BUBXaOfFjBlA4LsRODep04
    safe-exceptions-0.1.7.4-EnwlbRHRabWKOt2NJjFNWO stm-2.5.1.0
    tar-0.5.1.1-1OdByMcPlF4IHadwqcOBbW text-2.0.2 time-1.12.2
    unix-2.8.4.0 zlib-0.7.1.0-G1zW8erv3GXAKWUVuLjRT5

haddock-interfaces:   /usr/share/doc/cabal-install/html/cabal-install.haddock
haddock-html:         /usr/share/doc/cabal-install/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

